@@ -20,6 +20,7 @@ from .addRole import addRole
 from .getUserId import getUserId
 from .addUser import addUser
 from .addFx import addFx
+from .importFx import importFx
 from .createAccount import createAccount
 from .createBank import createBank
 from .createCustomer import createCustomer
@@ -38,7 +39,6 @@ from .getCardByCardNumber import getCardByCardNumber
 from .getAccountsHeld import getAccountsHeld
 from .getAccount import getAccountById
 from .getAccountTransactions import getAccountTransactions
-from .getViews import getViewsByProvider
 from .getCustomers import getCustomers
 from .deleteBranches import deleteBranches
 from .deleteCardById import deleteCardById
@@ -373,19 +373,6 @@ def addview(bank_id, account_id, name, description, metadata_view,
   else:
     exit(req.text)
 
-@cli.command(help="🧐 Get views by provider")
-@click.option('--bank-id', default="gh.29.uk.x", prompt=True)
-@click.option('--account-id', prompt=True)
-@click.option('--provider', prompt=True)
-@click.option('--provider-id', prompt=True)
-def getviews(bank_id, account_id, provider, provider_id):
-  req = getViewsByProvider(bank_id=bank_id, account_id=account_id, 
-                          provider=provider, provider_id=provider_id)
-  if req.status_code == 201 or req.status_code == 200:
-    click.echo(req.text)
-  else:
-    exit(req.text)
-
 @cli.command(help="🔗 Link user to a customer")
 @click.option('--bank-id', default="gh.29.uk.x", prompt=True)
 @click.option('--user-id', required=True, prompt=True)
@@ -490,6 +477,15 @@ def addfx(bank_id, from_currency, to_currency, conversion_value,
   else:
     exit(req.text)
 
+@cli.command(help="🚜 📉 Load all foreign exchange rates (FX) to all banks")
+def importfx():
+  from time import sleep
+  print("This will take a while.")
+  print("First we're going to download all the latest exchange rates for you.")
+  print("Then we'll post them to your OBP instance") 
+  sleep(5)
+  importFx()
+
 @cli.command(help="⚠️  🏦 Delete all branches")
 @click.option('--bank-id', required=True)
 def deletebranches(bank_id):
