@@ -7,6 +7,8 @@ import sys, traceback
 import re
 from .createAccount import createAccount
 from .createTransaction import createTransaction
+from .getUserIdByUsername import getUserIdByUsername
+from .hasEntitlements import hasEntitlements
 
 def importAccounts(spreadsheet=None, sheet_name=None):
   """
@@ -14,11 +16,21 @@ def importAccounts(spreadsheet=None, sheet_name=None):
 
   Requires roles/entitlement(s)
   - CanCreateAccount
-  - canCreateAnyTransactionRequest (for setting initial balance)
+  - CanCreateAnyTransactionRequest (for setting initial balance)
   """
   
   OBP_AUTH_TOKEN = get_config('OBP_AUTH_TOKEN')
   OBP_API_HOST = get_config('OBP_API_HOST')
+
+  # Validate entitlements
+  requiredEntitlements = ['CanCreateAccount', 'CanCreateAnyTransactionRequest',
+                          'CanGetAnyUser']
+  fail, msg = hasEntitlements(entitlements_required=requiredEntitlements)
+
+  if fail is True:
+    print(msg)
+    exit(-1)
+    
   '''
   Loading location data from ods spreadsheet
   '''
@@ -48,20 +60,17 @@ def importAccounts(spreadsheet=None, sheet_name=None):
       branch_id = get_value(7, account)
       account_routing_scheme = get_value(8, account)
       account_routing_address = get_value(9, account)
-      # Get user id based on usernamse (NOTE: User must exist in order for 
+      # Get user id based on username (NOTE: User must exist in order for 
       # import to succeed). Also, the user making the request must have the 
       # "CanGetAnyUser" entitlement. If you are a super user, you can use
       # `obp addrole --role-name CanGetAnyUser` to grant this entitlement to
       # yourself. 
-      authorization = 'DirectLogin token="{}"'.format(get_config('OBP_AUTH_TOKEN'))
-      headers = {'Content-Type': 'application/json',
-                'Authorization': authorization}
-      url = get_config('OBP_API_HOST') + '/obp/v3.1.0/users/username/{USERNAME}'.format(USERNAME=username)
-      response = requests.get(url, headers=headers)
-      if response.status_code is 200:
-        user_id = response.json()['user_id']
+      req = getUserIdByUsername(username=username)
+      if req.status_code is 200:
+        user_id = req.json()['user_id']
       else:
-        user_id = 'user not found'
+        print("ERROR: Could not determine user_id from username")
+        exit(-1)
 
       #Post accounts to api
       response = createAccount(bankid=bank_id, userid=user_id, currency=balance_currency, label=label,
@@ -77,7 +86,8 @@ def importAccounts(spreadsheet=None, sheet_name=None):
         # Set initial balance with transaction request
         # The create account api call must start with zero (0) so we
         # must create a transaction against the account to set initial balance
-        req = createTransaction(to_account_id=account_id, to_bank_id=bank_id, 
+        req = createTransaction(from_account_id=account_id, from_bank_id=bank_id,
+                        to_account_id=account_id, to_bank_id=bank_id, 
                         currency=balance_currency, amount=balance_amount, 
                         description="Opening balance",
                         challenge_type="SANDBOX_TAN")
